Async Reolink REST API

The is a client complete implementation of the REST interface for ReoLink cameras. This requries the base api and provides a Client class that can be used to access a camera via its REST/web interface.
